# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ClassificationGenericEnum(str, Enum):
    """
    EXTERNAL_RESOURCE_REFERENCE can be thought of as anything such as URL, URI, UNIX PATH, etc
    """

    """
    allowed enum values
    """
    CODE = 'CODE'
    TEXT = 'TEXT'
    IMAGE = 'IMAGE'
    VIDEO = 'VIDEO'
    EXTERNAL_RESOURCE_REFERENCE = 'EXTERNAL_RESOURCE_REFERENCE'
    UNKNOWN = 'UNKNOWN'
    FILE = 'FILE'

    @classmethod
    def from_json(cls, json_str: str) -> ClassificationGenericEnum:
        """Create an instance of ClassificationGenericEnum from a JSON string"""
        return ClassificationGenericEnum(json.loads(json_str))


