# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class MechanismEnum(str, Enum):
    """
    This will let us know how an asset was uploaded.  MANUAL: this is an event such as a user driven send to pieces, or a paste to pieces.  RECOMMENDED: This is an event that was initiall recommended via the suggestion flow, and a user decided totake the recommendation.  AUTOMATIC: This is not user driven at all and the asset was automatically uploaded via the suggestion flow. or other methods.  INTERNAL: This is an undelete able enum used for internal use only.
    """

    """
    allowed enum values
    """
    MANUAL = 'MANUAL'
    RECOMMENDED = 'RECOMMENDED'
    AUTOMATIC = 'AUTOMATIC'
    INTERNAL = 'INTERNAL'
    DELETED = 'DELETED'

    @classmethod
    def from_json(cls, json_str: str) -> MechanismEnum:
        """Create an instance of MechanismEnum from a JSON string"""
        return MechanismEnum(json.loads(json_str))


