# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ExternalProviderTypeEnum(str, Enum):
    """
    This is an enum to describe the provider used to authenticate a user.  IMPORTANT NOT to modify tha values here unless they are explicitly mapped with auth0's provider values(example within cloud server)  'waad': (windows azure active directory)
    """

    """
    allowed enum values
    """
    GITHUB = 'github'
    AUTH0 = 'auth0'
    GOOGLE_MINUS_OAUTH2 = 'google-oauth2'
    BITBUCKET = 'bitbucket'
    LINKEDIN = 'linkedin'
    TWITTER = 'twitter'
    FACEBOOK = 'facebook'
    WAAD = 'waad'

    @classmethod
    def from_json(cls, json_str: str) -> ExternalProviderTypeEnum:
        """Create an instance of ExternalProviderTypeEnum from a JSON string"""
        return ExternalProviderTypeEnum(json.loads(json_str))


